/*
    Antenna House PDF Tool API V6.0
    Java Interface sample program

    概要：ページ単位に分割

    Copyright 2018 Antenna House, Inc.
*/
import jp.co.antenna.ptl.*;

public class ExtractPage {

    public static void main(String[] args) {
        if(args.length < 2)
        {
            System.out.println("usage: java ExtractPage in-pdf-file out-base-file-name");
            return;
        }
        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);
            //ページコンテナの取得
            try (PtlPages pages = doc.getPages())
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空\n");
                    return;
                }
                // 文書プロパティの取得
                try (PtlDocProperty docproperty = doc.getDocProperty(); 
                    PtlDocInfo docinfo = docproperty.getDocInfo())
                {
                    // ページ数を取得
                    int wholePageNum = doc.getPageCount();
                    // 各ページの取得(index番号は0が先頭のためi=0からスタートさせる)
                    for(int i = 0; i < wholePageNum; i++)
                    {
                        try (PtlPage page = pages.get(i);
                            PtlPDFDocument doc_ext = new PtlPDFDocument(); // 出力側文書
                            PtlDocProperty docproperty_ext = doc_ext.getDocProperty(); // 出力側文書プロパティ
                            PtlDocInfo docinfo_ext = docproperty_ext.getDocInfo(); // 出力側文書情報の取得
                            PtlPages pages_ext = doc_ext.getPages())
                        {
                            // タイトルをコピー
                            docinfo_ext.setTitle(docinfo.getTitle());
                            // 著者をコピー
                            docinfo_ext.setAuthor(docinfo.getAuthor());
                            // サブジェクトをコピー
                            docinfo_ext.setSubject(docinfo.getSubject());
                            // キーワードをコピー
                            docinfo_ext.setKeywords(docinfo.getKeywords());
                            // クリエータをコピー
                            docinfo_ext.setCreator(docinfo.getCreator());
                            // プロデューサをコピー
                            docinfo_ext.setProducer(docinfo.getProducer());
                            // 作成日付をコピー
                            try (PtlDate dateCreate = docinfo.getCreationDate())
                            {
                                docinfo_ext.setCreationDate(dateCreate);
                            }
                            // 更新日付をコピー
                            try (PtlDate dateMod = docinfo.getModDate())
                            {
                                docinfo_ext.setModDate(dateMod);
                            }
                            // ページ挿入オプション
                            int insertoption = 0;
                            // ページの追加
                            pages_ext.append(doc, i, 1, insertoption);
                            // 出力ファイル名
                            String outputfile = (String)args[1] +  "_page_" + Integer.toString(i+1) + ".pdf";
                            try (PtlParamOutput outputFile = new PtlParamOutput(outputfile))
                            {
                                // ファイルに保存します。
                                doc_ext.save(outputFile);
                            }
                        }
                    }
                }
            }
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
